require "import"
import "android.widget.*"
import "android.view.*"
import "android.content.Context"
import "java.net.URL"
import "java.net.HttpURLConnection"
import "java.io.BufferedReader"
import "java.io.InputStreamReader"
import "android.os.Vibrator"
import "org.json.JSONObject"
import "android.content.Intent"
import "android.content.ClipData"
import "android.content.ClipboardManager"
import "android.net.ConnectivityManager"

activity = this

local gempaText = "Memuat data gempa terbaru..."
local sharedPreferences = activity.getSharedPreferences("GempaData", Context.MODE_PRIVATE)
function vibrate()
    local vibrator = activity.getSystemService(Context.VIBRATOR_SERVICE)
    if vibrator then vibrator.vibrate(40) end
end
function showToast(message)
    Toast.makeText(activity, message, Toast.LENGTH_SHORT).show()
end
function isInternetAvailable()
    local cm = activity.getSystemService(Context.CONNECTIVITY_SERVICE)
    local networkInfo = cm.getActiveNetworkInfo()
    return networkInfo ~= nil and networkInfo.isConnected()
end
function fetchBMKGData()
    local url = URL("https://data.bmkg.go.id/DataMKG/TEWS/autogempa.json")
    local connection = url.openConnection()
    connection.setRequestMethod("GET")
    local success, inputStream = pcall(function() return connection.getInputStream() end)
    if not success then return nil end
    local reader = BufferedReader(InputStreamReader(inputStream))
    local content = ""
    local line
    while true do
        line = reader.readLine()
        if not line then break end
        content = content.. line
    end
    reader.close()
    inputStream.close()
    return content
end
function parseBMKGData(jsonContent)
    local json = JSONObject(jsonContent)
    local gempa = json.getJSONObject("Infogempa").getJSONObject("gempa")
    return "Gempa bumi Terbaru:\n"..
           "Tanggal: ".. gempa.getString("Tanggal").. "\n"..
           "Waktu: ".. gempa.getString("Jam").. "\n"..
           "Magnitude: ".. gempa.getString("Magnitude").. "\n"..
           "Kedalaman: ".. gempa.getString("Kedalaman").. "\n"..
           "Lokasi: ".. gempa.getString("Wilayah").. "\n"..
           "Koordinat: ".. gempa.getString("Coordinates").. "\n"..
           "Lintang: ".. gempa.getString("Lintang").. "\n"..
           "Bujur: ".. gempa.getString("Bujur").. "\n"..
           "Potensi: ".. gempa.getString("Potensi").. "\n"..
           "Dirasakan: ".. gempa.getString("Dirasakan")
end
function updateGempaData()
    if isInternetAvailable() then
        local jsonContent = fetchBMKGData()
        if jsonContent then
            gempaText = parseBMKGData(jsonContent)
            local editor = sharedPreferences.edit()
            editor.putString("lastGempaData", gempaText)
            editor.apply()
        else
            gempaText = sharedPreferences.getString("lastGempaData", "Tidak ada data sebelumnya.")
        end
    else
        gempaText = sharedPreferences.getString("lastGempaData", "Tidak ada data sebelumnya.")
    end
    textView.setText(gempaText)
end
function copyToClipboard()
    vibrate()
local clipboard = activity.getSystemService(Context.CLIPBOARD_SERVICE)
    local clip = ClipData.newPlainText("Gempa BMKG", gempaText)
    clipboard.setPrimaryClip(clip)
end
function shareData()
    vibrate()
    local intent = Intent(Intent.ACTION_SEND)
    intent.setType("text/plain")
    intent.putExtra(Intent.EXTRA_TEXT, gempaText)
    activity.startActivity(Intent.createChooser(intent, "Bagikan info gempa"))
dlg.dismiss()
end

layout = {
    LinearLayout,
    orientation = "vertical",
    layout_width = "fill",
    layout_height = "fill",
    padding = "16dp",
    {
        TextView,
        id = "textView",
        text = gempaText,
        layout_width = "fill",
        layout_height = "wrap_content",
        textSize = "18sp",
        gravity = "center"
},
    {
        Button,
        id = "updateButton",
        text = "Perbarui Data",
        layout_width = "fill",
        layout_height = "wrap_content"
},
    {
        Button,
        id = "copyButton",
        text = "Salin",
        layout_width = "fill",
        layout_height = "wrap_content"
},
    {
        Button,
        id = "shareButton",
        text = "Bagikan",
        layout_width = "fill",
        layout_height = "wrap_content"
},
    {
        TextView,
        text = "© BMKG (Badan Meteorologi, Klimatologi, dan Geofisika). Credit by: Jm (https://t.me/jieshuojm).\nDilarang keras untuk memperdagangkan, merubah © & credit asli, dan mengunci kode yang terkait",
        layout_width = "fill",
        layout_height = "wrap_content",
        textSize = "16sp",
        gravity = "center"
},
    {
        Button,
        id = "closeButton",
        text = "Tutup",
        layout_width = "fill",
        layout_height = "wrap_content"
}
}
dlg = LuaDialog(activity)
dlg.setTitle("Data Gempa Saat Ini Dari BMKG")
dlg.setView(loadlayout(layout))
updateButton.onClick = function()
    updateGempaData() vibrate()
end
copyButton.onClick = function()
    copyToClipboard()
end
shareButton.onClick = function()
    shareData()
end
closeButton.onClick = function()
    vibrate()    dlg.dismiss()
end
updateGempaData()
vibrate() service.playSoundTick()
dlg.show()

